agentle.mcp.sampling.messages.image\_message\_content
=====================================================

.. automodule:: agentle.mcp.sampling.messages.image_message_content

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Base64Str
      BaseModel
      ImageMessageContent
   